import React from "react";
import { Button, Grid, makeStyles } from "@material-ui/core";
import { Alert } from "@material-ui/lab";
import { theme } from "../../../style/Theme";

const useStyles = makeStyles((theme) => ({
  infoBadge: {
    backgroundColor: theme.infoBadge.bgColor
  }
}));

export default function AlertMessages({ alerts }) {
  const classes = useStyles(theme);

  function determineSeverity(alarmType) {
    return ["error", "warning", "success"].includes(alarmType?.toLowerCase())
      ? alarmType?.toLowerCase()
      : "info";
  }

  function determineClassName(alarmType) {
    if (alarmType === "INFO") {
      return classes.infoBadge;
    }
  }

  return (
    <Grid
      id="ioc-alerts"
      container
      spacing={1}
      direction="column"
    >
      {alerts.map((alert) => (
        <Grid
          item
          key={alert?.message || alert}
        >
          <Alert
            className={determineClassName(alert?.type)}
            severity={determineSeverity(alert?.type)}
            action={
              alert?.link && (
                <Button
                  target="_blank"
                  href={alert.link}
                  color="inherit"
                  size="small"
                >
                  More Info
                </Button>
              )
            }
          >
            {alert?.message}
          </Alert>
        </Grid>
      ))}
    </Grid>
  );
}
