import React, { useCallback } from "react";
import { CustomTable } from "../common/table/CustomTable";
import { Grid, Tooltip } from "@material-ui/core";
import { noWrapText } from "../common/Helper";
import { useRedirect } from "../../hooks/Redirect";
import { JobStatusIcon, JobTypeIcon } from "./JobIcons";
import { formatDate } from "../common/Helper";

const jobLogColumns = [
  { id: "type", label: "Type", width: "8ch", textAlign: "center" },
  { id: "ioc", label: "IOC name", width: "15ch", sortable: false },
  { id: "version", label: "Revision", width: "10ch", sortable: false },
  { id: "host", label: "Host", width: "15ch", sortable: false },
  { id: "user", label: "User", width: "10ch", sortable: false },
  {
    id: "start",
    label: "Time",
    width: "15ch",
    sortable: false,
    textAlign: "right"
  }
];

function createGitVersionField(version, shortVersion) {
  return (
    <Tooltip
      title={version}
      arrow
      enterDelay={400}
    >
      <label>{noWrapText(shortVersion ?? version)}</label>
    </Tooltip>
  );
}

function createTableRow(job, deploymentId, colorStyle) {
  return {
    id: job.id,
    type: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <JobTypeIcon
          type={job.type}
          colorStyle={colorStyle}
        />
      </Grid>
    ),
    status: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <JobStatusIcon status={job.status} />
      </Grid>
    ),
    ioc: noWrapText(job.iocName),
    version: createGitVersionField(job.gitReference, job.sourceVersionShort),
    host: noWrapText(job.host?.hostName ?? null),
    network: noWrapText(job.host?.network ?? null),
    user: noWrapText(job.createdBy),
    start: noWrapText(formatDate(job.createdAt)),
    deploymentFailed: job.status === "FAILED" || job.status === "ERROR",
    jobType: job.type,
    iocId: job.iocId,
    deploymentId: job.deploymentId
  };
}

function createTableRowJobLog(job, deploymentId) {
  return createTableRow(job, deploymentId, "black");
}

export function JobTable({
  jobs,
  rowType = "jobLog",
  totalCount,
  lazyParams,
  setLazyParams,
  rowsPerPage,
  loading,
  deploymentId
}) {
  const tableTypeSpecifics = {
    jobLog: [jobLogColumns, createTableRowJobLog]
  };

  const redirect = useRedirect();
  const [columns, createRow] = tableTypeSpecifics[rowType];

  const itemLink = useCallback((item) => {
    if (["DEPLOY", "UNDEPLOY", "START", "STOP"].includes(item.jobType)) {
      return `/jobs/${item.id}`;
    }
  }, []);
  const onRowClicked = useCallback(
    (id, item) => {
      redirect(itemLink(item));
    },
    [itemLink, redirect]
  );

  return (
    <CustomTable
      columns={columns}
      rows={jobs?.map((job) => createRow(job, deploymentId))}
      handleRowClick={onRowClicked}
      itemLink={itemLink}
      totalCount={totalCount}
      lazyParams={lazyParams}
      setLazyParams={setLazyParams}
      rowsPerPage={rowsPerPage}
      loading={loading}
    />
  );
}
