import React from "react";
import { useSnackbar } from "notistack";
import { Button, makeStyles } from "@material-ui/core";

const useStyles = makeStyles((theme) => ({
  text: {
    color: "#f0f0f0",
    borderColor: "#f0f0f0",
    "&:hover": {
      backgroundColor: "#8d8d8d",
      borderColor: "#8d8d8d",
      boxShadow: "none"
    }
  }
}));

export function useCustomSnackbar() {
  const { enqueueSnackbar, closeSnackbar } = useSnackbar();
  const classes = useStyles();

  function showError(errorMessage, severity = "error") {
    console.error("Snackbar: " + errorMessage);
    const action = (key) => (
      <Button
        variant="text"
        classes={classes}
        onClick={() => {
          closeSnackbar(key);
        }}
      >
        Dismiss
      </Button>
    );
    enqueueSnackbar(errorMessage, {
      variant: severity,
      autoHideDuration: null,
      action
    });
  }

  return showError;
}
