import React from "react";
import {
  CheckCircleOutline,
  ErrorOutline,
  RotateRightOutlined,
  QueueOutlined,
  AddCircleOutline,
  RemoveCircleOutline
} from "@material-ui/icons";
import { Tooltip } from "@material-ui/core";
import { theme } from "../../style/Theme";

export function DeploymentStatusIcon({ status }) {
  const deploymentStatusIcons = {
    successful: {
      title: "Successful",
      icon: <CheckCircleOutline />
    },
    failed: {
      title: "Failed",
      icon: <ErrorOutline />
    },
    running: {
      title: "Running",
      icon: <RotateRightOutlined />
    },
    queued: {
      title: "Queued",
      icon: <QueueOutlined />
    }
  };

  const deploymentStatusColors = {
    successful: theme.palette.status.ok,
    failed: theme.palette.status.fail,
    running: theme.palette.status.progress,
    queued: theme.palette.status.progress
  };

  const state = status.toLowerCase();
  const iconStyle = { fill: deploymentStatusColors[state] };
  const iconTitle = deploymentStatusIcons[state].title;
  const statusIcon = deploymentStatusIcons[state].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}

export function DeploymentTypeIcon({ type }) {
  const deploymentTypeIcons = {
    deploy: {
      title: "Deployment",
      icon: <AddCircleOutline />
    },
    undeploy: {
      title: "Undeployment",
      icon: <RemoveCircleOutline />
    }
  };

  const iconStyle = { fill: theme.palette.status.icons };
  const iconTitle = deploymentTypeIcons[type.toLowerCase()].title;
  const statusIcon = deploymentTypeIcons[type.toLowerCase()].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}
